Diffrax Wrapper
===============


These are helper functions that wrap some function from the diffrax module like the
:meth:`diffrax.diffeqsolve` function. This is only done for convenience, to define
some default values for the parameters of the function. Don't hesitate to directly the
functions from the diffrax module if you need more flexibility.

Functions
---------

.. autofunction:: icomo.diffeqsolve

.. autofunction:: icomo.interpolate_func


